TerminalReaderReaderResourceInput

Struct TerminalReaderReaderResourceInput 

pub struct TerminalReaderReaderResourceInput {
    pub custom_text: Option<TerminalReaderReaderResourceCustomText>,
    pub email: Option<TerminalReaderReaderResourceEmail>,
    pub numeric: Option<TerminalReaderReaderResourceNumeric>,
    pub phone: Option<TerminalReaderReaderResourcePhone>,
    pub required: Option<bool>,
    pub selection: Option<TerminalReaderReaderResourceSelection>,
    pub signature: Option<TerminalReaderReaderResourceSignature>,
    pub skipped: Option<bool>,
    pub text: Option<TerminalReaderReaderResourceText>,
    pub toggles: Option<Vec<TerminalReaderReaderResourceToggle>>,
    pub type_: TerminalReaderReaderResourceInputType,
}
Represents an input to be collected using the reader

Fields

custom_text: Option<TerminalReaderReaderResourceCustomText>

Default text of input being collected.

email: Option<TerminalReaderReaderResourceEmail>numeric: Option<TerminalReaderReaderResourceNumeric>phone: Option<TerminalReaderReaderResourcePhone>required: Option<bool>

Indicate that this input is required, disabling the skip button.

selection: Option<TerminalReaderReaderResourceSelection>signature: Option<TerminalReaderReaderResourceSignature>skipped: Option<bool>

Indicate that this input was skipped by the user.

text: Option<TerminalReaderReaderResourceText>toggles: Option<Vec<TerminalReaderReaderResourceToggle>>

List of toggles being collected. Values are present if collection is complete.

type_: TerminalReaderReaderResourceInputType

Type of input being collected.