#[non_exhaustive]pub enum ProcessPaymentIntentTerminalReaderProcessConfigAllowRedisplay {
Always,
Limited,
Unspecified,
Unknown(String),
}Expand description
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Always
Limited
Unspecified
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations