pub struct CollectInputsTerminalReaderInputsCustomText {
pub description: Option<String>,
pub skip_button: Option<String>,
pub submit_button: Option<String>,
pub title: String,
}Expand description
Customize the text which will be displayed while collecting this input
Fields
description: Option<String>The description which will be displayed when collecting this input
Custom text for the skip button. Maximum 14 characters.
Custom text for the submit button. Maximum 30 characters.
title: StringThe title which will be displayed when collecting this input
Implementations