pub struct ProcessPaymentIntentTerminalReaderProcessConfig {
pub allow_redisplay: Option<ProcessPaymentIntentTerminalReaderProcessConfigAllowRedisplay>,
pub enable_customer_cancellation: Option<bool>,
pub return_url: Option<String>,
pub skip_tipping: Option<bool>,
pub tipping: Option<TippingConfig>,
}Expand description
Configuration overrides for this transaction, such as tipping and customer cancellation settings.
Fields
allow_redisplay: Option<ProcessPaymentIntentTerminalReaderProcessConfigAllowRedisplay>This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.
enable_customer_cancellation: Option<bool>Enables cancel button on transaction screens.
return_url: Option<String>The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme.
skip_tipping: Option<bool>Override showing a tipping selection screen on this transaction.
tipping: Option<TippingConfig>Tipping configuration for this transaction.
Implementations