pub struct ProcessSetupIntentTerminalReader { /* private fields */ }Expand description
Initiates a SetupIntent flow on a Reader. See Save directly without charging for more details.
Implementations
Sourceimpl ProcessSetupIntentTerminalReader
impl ProcessSetupIntentTerminalReader
Sourcepub fn new(
reader: impl Into<TerminalReaderId>,
allow_redisplay: impl Into<ProcessSetupIntentTerminalReaderAllowRedisplay>,
setup_intent: impl Into<String>,
) -> Self
pub fn new( reader: impl Into<TerminalReaderId>, allow_redisplay: impl Into<ProcessSetupIntentTerminalReaderAllowRedisplay>, setup_intent: impl Into<String>, ) -> Self
Construct a new ProcessSetupIntentTerminalReader.
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn process_config(
self,
process_config: impl Into<ProcessSetupIntentTerminalReaderProcessConfig>,
) -> Self
pub fn process_config( self, process_config: impl Into<ProcessSetupIntentTerminalReaderProcessConfig>, ) -> Self
Configuration overrides for this setup, such as MOTO and customer cancellation settings.
Sourceimpl ProcessSetupIntentTerminalReader
impl ProcessSetupIntentTerminalReader
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.