pub struct SetReaderDisplayTerminalReader { /* private fields */ }Expand description
Sets the reader display to show cart details.
Implementations
Sourceimpl SetReaderDisplayTerminalReader
impl SetReaderDisplayTerminalReader
Sourcepub fn new(
reader: impl Into<TerminalReaderId>,
type_: impl Into<SetReaderDisplayTerminalReaderType>,
) -> Self
pub fn new( reader: impl Into<TerminalReaderId>, type_: impl Into<SetReaderDisplayTerminalReaderType>, ) -> Self
Construct a new SetReaderDisplayTerminalReader.
Sourcepub fn cart(self, cart: impl Into<SetReaderDisplayTerminalReaderCart>) -> Self
pub fn cart(self, cart: impl Into<SetReaderDisplayTerminalReaderCart>) -> Self
Cart details to display on the reader screen, including line items, amounts, and currency.
Sourceimpl SetReaderDisplayTerminalReader
impl SetReaderDisplayTerminalReader
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.